{% extends "base.html" %}

{% block title %}Главная страница{% endblock %}

{% block content %}
<h1>Добро пожаловать в Fladoja!</h1>
<p>Текущее время: {{ current_time }}</p>

<div class="features">
    <h3>Возможности фреймворка:</h3>
    <ul>
        <li>Простая маршрутизация</li>
        <li>Встроенная админка</li>
        <li>Система шаблонов</li>
    </ul>
</div>
{% endblock %}